@@ -6,8 +6,8 @@ use serde::{
 };
 
 use crate::registry::{
-    MetaApi, MetaInfo, MetaPath, MetaResponses, MetaSchema, MetaSchemaRef, MetaSecurityScheme,
-    MetaServer, Registry,
+    MetaApi, MetaExternalDocument, MetaInfo, MetaPath, MetaResponses, MetaSchema, MetaSchemaRef,
+    MetaSecurityScheme, MetaServer, MetaWebhook, Registry,
 };
 
 const OPENAPI_VERSION: &str = "3.0.0";
@@ -64,11 +64,25 @@ impl Serialize for MetaResponses {
     }
 }
 
+struct WebhookMap<'a>(&'a [MetaWebhook]);
+
+impl<'a> Serialize for WebhookMap<'a> {
+    fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
+        let mut s = serializer.serialize_map(Some(self.0.len()))?;
+        for webhook in self.0 {
+            s.serialize_entry(&webhook.name, &webhook.operation)?;
+        }
+        s.end()
+    }
+}
+
 pub(crate) struct Document<'a> {
     pub(crate) info: &'a MetaInfo,
     pub(crate) servers: &'a [MetaServer],
     pub(crate) apis: &'a [MetaApi],
+    pub(crate) webhooks: &'a [MetaWebhook],
     pub(crate) registry: &'a Registry,
+    pub(crate) external_document: Option<&'a MetaExternalDocument>,
 }
 
 impl<'a> Serialize for Document<'a> {
@@ -87,6 +101,9 @@ impl<'a> Serialize for Document<'a> {
         s.serialize_field("info", &self.info)?;
         s.serialize_field("servers", self.servers)?;
         s.serialize_field("tags", &self.registry.tags)?;
+        if !self.webhooks.is_empty() {
+            s.serialize_field("webhooks", &WebhookMap(self.webhooks))?;
+        }
         s.serialize_field("paths", &PathMap(self.apis))?;
         s.serialize_field(
             "components",
@@ -95,6 +112,7 @@ impl<'a> Serialize for Document<'a> {
                 security_schemes: &self.registry.security_schemes,
             },
         )?;
+        s.serialize_field("externalDocs", &self.external_document)?;
 
         s.end()
     }
